/** @jsx jsx */
import { css, jsx } from '@emotion/core'
import { useState } from 'react'
import Main from './components/main'
import Parts from './components/parts'
import Colors from './components/colors'
import TwoCols from './components/twoCols.js'
import LeftCol from './components/leftCol.js'
import Designer from './components/designer.js'
import Summary from './components/summary'
import Menu from './components/menu'
import Logo from './img/czu.jpg'
import { BrowserRouter as Router, Switch, Route } from 'react-router-dom'

function App() {
  const [parameters, setParameters] = useState({
    width: 0.8,
    height: 2.2,
    depth: 1,
    color: '#8b572a',
    backDesk: '1',
    bottomDesk: '1',
    topDesk: '1',
    deskWidth: 0.02,
    parts: 1,
    currentPart: 1,
    step: 1,
    showCurrent: true,
    currentColor: '#7ED321',
    bgColor: '#d1b283',
    configuration: [3, 3, 3, 3, 3],
    name: '',
    surName: '',
    email: '',
    street: '',
    cp: '',
    zip: '',
    phone: '',
    note: ''
  })
  return (
    <Router>
      <div
        className='App'
        css={css`
          max-width: 80%;
          margin: auto;
          height: 100vh;
          display: flex;
          flex-direction: column;
        `}
      >
        <header
          css={css`
            display: grid;
            margin-top: 10px;
            background-color: #1a3a3a;
            color: #e7e2f6;
            margin-bottom: 10px;
            border-radius: 10px;
          `}
        >
          <h1
            css={css`
              text-align: center;
              text-transform: uppercase;
            `}
          >
            3D konfigurátor nábytku
          </h1>
        </header>
        <Switch>
          <Route exact path='/'>
            <TwoCols>
              <LeftCol>
                <Menu parameters={parameters} setParameters={setParameters} />
                <Main parameters={parameters} setParameters={setParameters} />
              </LeftCol>
              <Designer
                parameters={parameters}
                setParameters={setParameters}
              ></Designer>
            </TwoCols>
          </Route>
          <Route path='/colors/'>
            <TwoCols>
              <LeftCol>
                <Menu parameters={parameters} setParameters={setParameters} />
                <Colors parameters={parameters} setParameters={setParameters} />
              </LeftCol>
              <Designer
                parameters={parameters}
                setParameters={setParameters}
              ></Designer>
            </TwoCols>
          </Route>
          <Route path='/parts/'>
            <TwoCols>
              <LeftCol>
                <Menu parameters={parameters} setParameters={setParameters} />
                <Parts parameters={parameters} setParameters={setParameters} />
              </LeftCol>
              <Designer
                parameters={parameters}
                setParameters={setParameters}
              ></Designer>
            </TwoCols>
          </Route>
          <Route path='/summary/'>
            <TwoCols>
              <LeftCol>
                <Menu parameters={parameters} setParameters={setParameters} />
                <Summary
                  parameters={parameters}
                  setParameters={setParameters}
                />
              </LeftCol>
              <Designer
                parameters={parameters}
                setParameters={setParameters}
              ></Designer>
            </TwoCols>
          </Route>
          <Route path='*'>404</Route>
        </Switch>
        <footer
          css={css`
            background: #1a3a3a;
            color: white;
            text-align: center;
            padding: 20px;
            border-radius: 5px;
            margin: 10px 0;
          `}
        >
          <div
            css={css`
              display: flex;
              justify-content: space-between;
              align-items: center;
            `}
          >
            <div
              css={css`
                text-align: left;
              `}
            >
              Tento projekt byl zpracován jako diplomová práce na České
              zemědělské univerzitě v Praze. <br /> Autor: David Holada, 2020
            </div>
            <img
              src={Logo}
              css={css`
                width: 100px;
                border-radius: 10px;
              `}
              alt='Logo ČZU'
            />
          </div>
        </footer>
      </div>
    </Router>
  )
}

export default App
