/** @jsx jsx */
import React, { useState } from 'react'
import { css, jsx } from '@emotion/core'
import ResizeIcon from '../img/3d.svg'
import ResizeIconActive from '../img/3d-active.svg'
import ColorIcon from '../img/art.svg'
import ColorIconActive from '../img/art-active.svg'
import SummaryIcon from '../img/summary.svg'
import SummaryIconActive from '../img/summary-active.svg'
import PartsIcon from '../img/parts.svg'
import PartsIconActive from '../img/parts-active.svg'
import { Link, useLocation } from 'react-router-dom'

function Menu(props) {
  const parameters = props.parameters
  const setParameters = props.setParameters

  const [resizeUrl, setResizeUrl] = useState(ResizeIconActive)
  const [colorUrl, setColorUrl] = useState(ColorIcon)
  const [summaryUrl, setSummaryUrl] = useState(SummaryIcon)
  const [partsUrl, setPartsUrl] = useState(PartsIcon)

  const location = useLocation()

  return (
    <div
      css={css`
        border-bottom: 1px solid #3c3941;
        display: flex;
        a {
          margin-right: 15px;
        }
        img {
          display: flex;
          background-color: #e7e2f6;
          border-top-left-radius: 6px;
          border-top-right-radius: 6px;
          padding: 5px;
          width: 40px;
        }
      `}
    >
      <Link
        to='/'
        onClick={() => {
          setColorUrl(ColorIcon)
          setResizeUrl(ResizeIconActive)
          setSummaryUrl(SummaryIcon)
          setPartsUrl(PartsIcon)
          setParameters({ ...parameters, step: 1 })
        }}
      >
        <img
          src={resizeUrl}
          onMouseOver={() => setResizeUrl(ResizeIconActive)}
          onMouseOut={() =>
            setResizeUrl(
              location.pathname !== '/' ? ResizeIcon : ResizeIconActive
            )
          }
        />
      </Link>
      <Link
        to='/colors/'
        onClick={() => {
          setColorUrl(ColorIconActive)
          setResizeUrl(ResizeIcon)
          setSummaryUrl(SummaryIcon)
          setPartsUrl(PartsIcon)
          setParameters({ ...parameters, step: 2 })
        }}
      >
        <img
          src={colorUrl}
          onMouseOver={() => setColorUrl(ColorIconActive)}
          onMouseOut={() =>
            setColorUrl(
              location.pathname !== '/colors/' ? ColorIcon : ColorIconActive
            )
          }
        />
      </Link>
      <Link
        to='/parts/'
        onClick={() => {
          setColorUrl(ColorIcon)
          setResizeUrl(ResizeIcon)
          setSummaryUrl(SummaryIcon)
          setPartsUrl(PartsIconActive)
          setParameters({ ...parameters, step: 3 })
        }}
      >
        <img
          src={partsUrl}
          onMouseOver={() => setPartsUrl(PartsIconActive)}
          onMouseOut={() =>
            setPartsUrl(
              location.pathname !== '/parts/' ? PartsIcon : PartsIconActive
            )
          }
        />
      </Link>
      <Link
        to='/summary/'
        onClick={() => {
          setColorUrl(ColorIcon)
          setResizeUrl(ResizeIcon)
          setSummaryUrl(SummaryIconActive)
          setPartsUrl(PartsIcon)
          setParameters({ ...parameters, step: 4 })
        }}
      >
        <img
          src={summaryUrl}
          onMouseOver={() => setSummaryUrl(SummaryIconActive)}
          onMouseOut={() =>
            setSummaryUrl(
              location.pathname !== '/summary/'
                ? SummaryIcon
                : SummaryIconActive
            )
          }
        />
      </Link>
    </div>
  )
}

export default Menu
