import React from 'react'
import { useThree } from 'react-three-fiber'

function Scene(props) {
  const {
    camera,
    gl: { domElement }
  } = useThree()

  const Cube = props => {
    let color = parseInt(props.color.replace('#', '0x'), 16)
    return (
      <mesh position={props.position} onClick={props.onClick}>
        <boxBufferGeometry attach='geometry' args={props.size} />
        <meshStandardMaterial attach='material' color={color} />
      </mesh>
    )
  }

  const halfToLeft = -(props.parameters.width * props.parameters.parts) / 2

  return (
    <>
      {Array(parseInt(props.parameters.parts))
        .fill(1)
        .map((el, i) => (
          <>
            {props.parameters.topDesk === '1' && (
              <Cube
                size={[
                  props.parameters.width,
                  props.parameters.deskWidth,
                  props.parameters.depth
                ]}
                position={[
                  halfToLeft +
                    (i + 1) * props.parameters.width -
                    props.parameters.width / 2, //horni stena
                  0.5 -
                    props.parameters.deskWidth / 2 +
                    (props.parameters.height - 1) * 0.5,
                  0
                ]}
                color={
                  props.parameters.currentPart === i + 1 &&
                  props.parameters.step === 3 &&
                  props.parameters.showCurrent === true
                    ? props.parameters.currentColor
                    : props.parameters.color
                }
                onClick={e => {
                  props.setParameters({
                    ...props.parameters,
                    currentPart: i + 1
                  })
                  e.stopPropagation()
                }}
              />
            )}
            {props.parameters.bottomDesk === '1' && (
              <Cube
                size={[
                  props.parameters.width,
                  props.parameters.deskWidth,
                  props.parameters.depth
                ]}
                position={[
                  halfToLeft +
                    (i + 1) * props.parameters.width -
                    props.parameters.width / 2, //dolni stena
                  -0.5 +
                    props.parameters.deskWidth / 2 -
                    (props.parameters.height - 1) * 0.5,
                  0
                ]}
                color={
                  props.parameters.currentPart === i + 1 &&
                  props.parameters.step === 3 &&
                  props.parameters.showCurrent === true
                    ? props.parameters.currentColor
                    : props.parameters.color
                }
                onClick={e => {
                  props.setParameters({
                    ...props.parameters,
                    currentPart: i + 1
                  })
                  e.stopPropagation()
                }}
              />
            )}
            {props.parameters.backDesk === '1' && (
              <Cube
                size={[
                  props.parameters.width,
                  props.parameters.height,
                  props.parameters.deskWidth
                ]} //zadni stena
                position={[
                  halfToLeft +
                    (i + 1) * props.parameters.width -
                    props.parameters.width / 2,
                  0,
                  -0.5 +
                    props.parameters.deskWidth / 2 -
                    (props.parameters.depth - 1) * 0.5
                ]}
                color={
                  props.parameters.currentPart === i + 1 &&
                  props.parameters.step === 3 &&
                  props.parameters.showCurrent === true
                    ? props.parameters.currentColor
                    : props.parameters.color
                }
                onClick={e => {
                  props.setParameters({
                    ...props.parameters,
                    currentPart: i + 1
                  })
                  e.stopPropagation()
                }}
              />
            )}
            <Cube
              size={[
                props.parameters.currentPart === 1
                  ? props.parameters.deskWidth
                  : props.parameters.deskWidth / 2,
                props.parameters.height,
                props.parameters.depth
              ]} //leva stena
              position={[halfToLeft + i * props.parameters.width, 0, 0]}
              color={
                props.parameters.currentPart === i + 1 &&
                props.parameters.step === 3 &&
                props.parameters.showCurrent === true
                  ? props.parameters.currentColor
                  : props.parameters.color
              }
              onClick={e => {
                props.setParameters({
                  ...props.parameters,
                  currentPart: i + 1
                })
                e.stopPropagation()
              }}
            />
            <Cube
              size={[
                i === props.parameters.parts - 1
                  ? props.parameters.deskWidth
                  : props.parameters.deskWidth / 2,
                props.parameters.height,
                props.parameters.depth
              ]} //prava
              position={[
                halfToLeft +
                  (i + 1) * props.parameters.width -
                  props.parameters.deskWidth / 2,
                0,
                0
              ]}
              color={
                props.parameters.currentPart === i + 1 &&
                props.parameters.step === 3 &&
                props.parameters.showCurrent === true
                  ? props.parameters.currentColor
                  : props.parameters.color
              }
              onClick={e => {
                props.setParameters({
                  ...props.parameters,
                  currentPart: i + 1
                })
                e.stopPropagation()
              }}
            />
            ))}
            {Array(parseInt(props.parameters.configuration[i]))
              .fill(1)
              .map((el, j) => (
                <Cube
                  size={[
                    props.parameters.width,
                    props.parameters.deskWidth,
                    props.parameters.depth * 0.95
                  ]}
                  position={[
                    halfToLeft +
                      (i + 1) * props.parameters.width -
                      props.parameters.width / 2, //polička
                    props.parameters.height / 2 -
                      (j + 1) *
                        (props.parameters.height /
                          (parseInt(props.parameters.configuration[i]) + 1)),
                    0
                  ]}
                  color={
                    props.parameters.currentPart === i + 1 &&
                    props.parameters.step === 3 &&
                    props.parameters.showCurrent === true
                      ? props.parameters.currentColor
                      : props.parameters.color
                  }
                  onClick={e => {
                    props.setParameters({
                      ...props.parameters,
                      currentPart: i + 1
                    })
                    e.stopPropagation()
                  }}
                  key={j}
                />
              ))}
          </>
        ))}

      <orbitControls args={[camera, domElement]} />
      <ambientLight intensity={0.5} />
      <pointLight intensity={0.5} position={[0, 0, -5]} />
      <pointLight intensity={0.5} position={[0, 1, -5]} />
      <pointLight intensity={0.5} position={[0, -1, -5]} />
    </>
  )
}

export default Scene
