/** @jsx jsx */
import React, { useState } from 'react'
import { css, jsx } from '@emotion/core'

function Summary(props) {
  const parameters = props.parameters

  const setParameters = props.setParameters

  const [send, setSend] = useState(0)

  const createIssue = newIssue => {
    fetch('/api/post', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json'
      },
      body: JSON.stringify(newIssue)
    })
      .then(response => response.json())
      .then(data => {
        console.log('Success:', data)
      })
      .catch(error => {
        console.error('Error:', error)
      })
  }

  function handleSubmit(e) {
    createIssue(parameters)
    setParameters({
      ...parameters,
      name: '',
      surName: '',
      email: '',
      street: '',
      cp: '',
      zip: '',
      phone: '',
      note: ''
    })
    setSend(1)
    e.preventDefault()
  }

  function handleChange(e) {
    const value = e.target.value
    setParameters({ ...parameters, [e.target.name]: value })
  }
  return (
    <div
      css={css`
        flex-grow: 1;
        display: flex;
        flex-direction: column;
      `}
    >
      <h2>Odeslání objednávky</h2>
      <form
        onSubmit={e => handleSubmit(e)}
        css={css`
          display: flex;
          justify-content: space-between;
          flex-direction: column;
          flex-grow: 1;
        `}
      >
        <div>
          {send === 1 && (
            <div
              css={css`
                background: #60a26b;
                margin-bottom: 10px;
                padding: 10px;
                color: white;
              `}
            >
              Objednávka byla odeslána. Děkujeme!
            </div>
          )}
          <div
            className='column'
            css={css`
              grid-row-gap: 10px;
            `}
          >
            <label>Jméno:</label>
            <input
              type='text'
              name='name'
              value={parameters.name}
              onChange={e => handleChange(e)}
              required={send === 0 ? 1 : 0}
            />
            <label>Příjmení:</label>
            <input
              type='text'
              name='surName'
              value={parameters.surName}
              onChange={e => handleChange(e)}
              required={send === 0 ? 1 : 0}
            />
            <label>E-mail:</label>
            <input
              type='email'
              name='email'
              value={parameters.email}
              onChange={e => handleChange(e)}
              required={send === 0 ? 1 : 0}
            />
            <label>Ulice:</label>
            <input
              type='text'
              name='street'
              value={parameters.street}
              onChange={e => handleChange(e)}
              required={send === 0 ? 1 : 0}
            />
            <label>Č. p.:</label>
            <input
              type='text'
              name='cp'
              value={parameters.cp}
              onChange={e => handleChange(e)}
              required={send === 0 ? 1 : 0}
            />
            <label>PSČ:</label>
            <input
              type='text'
              name='zip'
              value={parameters.zip}
              onChange={e => handleChange(e)}
              required={send === 0 ? 1 : 0}
            />
            <label>Telefon:</label>
            <input
              type='tel'
              name='phone'
              value={parameters.phone}
              onChange={e => handleChange(e)}
              required={send === 0 ? 1 : 0}
            />
            <label
              css={css`
                align-self: flex-start;
              `}
            >
              Poznámka:
            </label>
            <textarea
              name='note'
              value={parameters.note}
              onChange={e => handleChange(e)}
            />
          </div>
        </div>
        <input
          type='submit'
          value='Odeslat objednávku'
          css={css`
            width: 100%;
            height: 50px;
            background: #60a26b;
            color: white;
            text-transform: uppercase;
            font-weight: 600;
            border-radius: 3px;
            cursor: pointer;
          `}
        />
      </form>
    </div>
  )
}

export default Summary
